validator

package
v0.0.0-...-86a93a3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 29, 2026 License: Apache-2.0 Imports: 5 Imported by: 0

Documentation

Index

Constants

const SolanaAddressLength = 44

Length of a Solana public key in base‑58

Variables

This section is empty.

Functions

func ValidateDuration

func ValidateDuration(s string) error

func ValidateNumber

func ValidateNumber(s string) error

func ValidateSolana

func ValidateSolana(prefix, suffix, pattern string) error

ValidateSolana checks that prefix, suffix and (optionally) a regexp pattern could still match a valid 44‑char Solana public key.

func ValidateTimeout

func ValidateTimeout(s string) (time.Duration, error)

ValidateTimeout checks if the provided timeout string is valid It accepts either a pure number (interpreted as seconds) or a duration string format

Types

This section is empty.

Jump to